==> release-1.6.tar.gz: website/docs/home/index.md <==
---
assignees:
- bgrant0607
- thockin
title: Kubernetes Documentation
redirect_from:
- "/docs/"
- "/docs/index.html"
- "/docs/user-guide/"
- "/docs/user-guide/index.html"
---

Kubernetes documentation can help you set up Kubernetes, learn about the system, or get your applications and workloads running on Kubernetes. To learn the basics of what Kubernetes is and how it works, read "[What is Kubernetes](/docs/concepts/overview/what-is-kubernetes/)".

## Interactive Tutorial

The [Kubernetes Basics interactive tutorial](/docs/tutorials/kubernetes-basics/) lets you try out Kubernetes right out of your web browser, using a virtual terminal. Learn about the Kubernetes system and deploy, expose, scale, and upgrade a containerized application in just a few minutes.

## Installing/Setting Up Kubernetes

[Picking the Right Solution](/docs/getting-started-guides/) can help you get a Kubernetes cluster up and running, either for local development, or on your cloud provider of choice.

Other/newer ways to set up a Kubernetes cluster include:

* [Minikube](/docs/getting-started-guides/minikube/): Install a single-node Kubernetes cluster on your local machine for development and testing.
* [Installing Kubernetes on AWS with kops](/docs/getting-started-guides/kops/): Bring up a complete Kubernetes cluster on Amazon Web Services, using a tool called `kops`.
* [Installing Kubernetes on Linux with kubeadm](/docs/getting-started-guides/kubeadm/) (Beta): Install a secure Kubernetes cluster on any pre-existing machines running Linux, using the built-in `kubeadm` tool.
* [Installing Kubernetes On-premise/Cloud Providers with Kubespray](/docs/getting-started-guides/kubespray/): Deploy a Kubernetes cluster on-premises baremetal or hosted on cloud providers, with Ansible and `kubespray` tools.
* [Installing Kubernetes on Ubuntu](/docs/getting-started-guides/ubuntu/): Deploy a Kubernetes cluster on-premise, baremetal, cloud providers, or localhost with Charms and `conjure-up`.

## Concepts, Tasks, and Tutorials

The Kubernetes documentation contains a number of resources to help you understand and work with Kubernetes.

* [Concepts](/docs/concepts/) provide a deep understanding of how Kubernetes works.
* [Tasks](/docs/tasks/) contain step-by-step instructions for common Kubernetes tasks.
* [Tutorials](/docs/tutorials/) contain detailed walkthroughs of the Kubernetes workflow.

## API and Command References

The [Reference](/docs/reference/) documentation provides complete information on the Kubernetes APIs and the `kubectl` command-line interface.

## Tools

The [Tools](/docs/tools/) page contains a list of native and third-party tools for Kubernetes.

## Troubleshooting

The [Troubleshooting](/docs/tasks/debug-application-cluster/troubleshooting) page outlines some resources for troubleshooting and finding help.

## Frequently Asked Questions

* [User FAQ](https://github.com/kubernetes/kubernetes/wiki/User-FAQ)
* [Debugging FAQ](https://github.com/kubernetes/kubernetes/wiki/Debugging-FAQ)
* [Services FAQ](https://github.com/kubernetes/kubernetes/wiki/Services-FAQ)

==> release-1.7.tar.gz: website/docs/home/index.md <==
---
approvers:
- bgrant0607
- thockin
title: Kubernetes Documentation
---

Kubernetes documentation can help you set up Kubernetes, learn about the system, or get your applications and workloads running on Kubernetes. To learn the basics of what Kubernetes is and how it works, read "[What is Kubernetes](/docs/concepts/overview/what-is-kubernetes/)".

## Interactive Tutorial

The [Kubernetes Basics interactive tutorial](/docs/tutorials/kubernetes-basics/) lets you try out Kubernetes right out of your web browser, using a virtual terminal. Learn about the Kubernetes system and deploy, expose, scale, and upgrade a containerized application in just a few minutes.

## Installing/Setting Up Kubernetes

[Picking the Right Solution](/docs/setup/pick-right-solution/) can help you get a Kubernetes cluster up and running, either for local development, or on your cloud provider of choice.

## Concepts, Tasks, and Tutorials

The Kubernetes documentation contains a number of resources to help you understand and work with Kubernetes.

* [Concepts](/docs/concepts/) provide a deep understanding of how Kubernetes works.
* [Tasks](/docs/tasks/) contain step-by-step instructions for common Kubernetes tasks.
* [Tutorials](/docs/tutorials/) contain detailed walkthroughs of the Kubernetes workflow.

## API and Command References

The [Reference](/docs/reference/) documentation provides complete information on the Kubernetes APIs and the `kubectl` command-line interface.

## Tools

The [Tools](/docs/tools/) page contains a list of native and third-party tools for Kubernetes.

## Troubleshooting

The [Troubleshooting](/docs/tasks/debug-application-cluster/troubleshooting) page outlines some resources for troubleshooting and finding help.
